import type { ZegoLogger } from "zego-express-engine-webrtm";
import { StreamView } from "../streamView/streamView";
import { ZegoCaptureScreenAudio, ZegoCaptureScreenVideo, ZegoCustomVideo } from "../../../common/zego.entity";
import { ZegoServerResponse, ZegoSnapshotOptions, ZegoStreamUpdateType, ZegoLocalViewOptions, ZegoLocalAduioOptions, ZegoLocalStreamEvent } from "../../../../code/zh/ZegoExpressEntity.web";
import EventManager from "../../../util/eventManager";
import { ZegoStreamOptions, ZegoCaptureMicrophone, ZegoCaptureCamera, ZegoCustomAudio } from "../../../common/zego.entity";
import { PublishModule } from "../publishModules";
import { ZegoStreamCenterWeb } from "../zego.streamCenter.web";
import { AdvancedModule } from "../../../modules/advance/advancedModule";
import { ZegoPreview } from "../publishModules/zego.preview";
import { StateCenter } from "../../../common/stateCenter";
export declare class ZegoCaptureStream {
    private _zgp_options;
    private _zgp_logger;
    private _zgp_streamCenter;
    private _zgp_stateCenter;
    private _zgp_publishModule;
    private _zgp_advancedModule;
    get active(): boolean;
    id: string;
    originVideoStream: MediaStream | null;
    originAudioStream: MediaStream | null;
    audioMuted: boolean;
    audioCaptureMuted: boolean;
    stream: MediaStream | null;
    private _zgp_ACacheStreams;
    private _zgp_VCacheStreams;
    eventHandler: {
        autoplayFailed: (player: HTMLMediaElement, e?: any) => void;
        autoplayCaptureFailed: (player: HTMLMediaElement, e?: any) => void;
        canPlayAudio: (e: any) => void;
        canPlayVideo: (e: any) => void;
        canPlayCaptureVideo: (e: any) => void;
        canPlayCaptureAudio: (e: any) => void;
    };
    eventManager: EventManager;
    get view(): HTMLElement | null;
    isPlayingVideo: boolean;
    isPlayingCaptureVideo: boolean;
    get autoPlay(): boolean;
    getAudioTracks(): MediaStreamTrack[] | [];
    getVideoTracks(): MediaStreamTrack[] | [];
    getTracks(): MediaStreamTrack[] | [];
    aCaptureViewer: StreamView | null;
    vCaptureViewers: StreamView[];
    videoWrappers: HTMLElement[];
    viewer: StreamView | null;
    private _zgp_previewer;
    originStreamPreviewType: string;
    streamPreviewType: string;
    originVideoTrack: MediaStreamTrack | null;
    originAudioTrack: MediaStreamTrack | null;
    get videoDeviceId(): string;
    get audioDeviceId(): string;
    constructor(_zgp_options: ZegoStreamOptions, _zgp_logger: ZegoLogger, _zgp_streamCenter: ZegoStreamCenterWeb, _zgp_stateCenter: StateCenter, _zgp_publishModule: PublishModule, _zgp_advancedModule: AdvancedModule);
    on<k extends keyof ZegoLocalStreamEvent>(event: k, callBack: ZegoLocalStreamEvent[k]): boolean;
    off<k extends keyof ZegoLocalStreamEvent>(event: k, callBack?: ZegoLocalStreamEvent[k]): boolean;
    startPublish(): void;
    replacePublish(type?: ZegoStreamUpdateType, stream?: MediaStream): void;
    resetPublish(): void;
    private _getDeviceIdByTrack;
    private _zgp_handleCapture;
    private _zgp_updateOriginStream;
    get isPublish(): boolean;
    updateStreamAudioTrack(successFn?: Function, failFn?: Function, action?: 0 | 1): Promise<void>;
    updateStreamVideoTrack(successFn?: Function, failFn?: Function, action?: 0 | 1): Promise<void>;
    updateStreamVideoAndAudio(successFn?: Function, failFn?: Function, action?: 0 | 1): Promise<void>;
    private _updateStreamTrack;
    private _zgp_initPreviewer;
    createZegoStreamPreview(stream: MediaStream, onlyPreview: boolean, previewType?: "camera" | "custom" | "screen"): ZegoPreview;
    private checkPreview;
    private _zgp_updatePreviewer;
    private _getVideoBitrate;
    private _getAudioBitrate;
    private _createStream;
    startCaptureMicrophone(options?: ZegoCaptureMicrophone): Promise<ZegoServerResponse>;
    startCaptureCamera(options?: ZegoCaptureCamera): Promise<ZegoServerResponse>;
    startCaptureCameraAndMicrophone(cameraOptions?: ZegoCaptureCamera, microphoneOptions?: ZegoCaptureMicrophone): Promise<ZegoServerResponse>;
    autoCapture(): Promise<ZegoServerResponse>;
    startCaptureCustomAudio(options: ZegoCustomAudio): Promise<ZegoServerResponse>;
    startCaptureCustomVideo(options: ZegoCustomVideo): Promise<ZegoServerResponse>;
    startCaptureCustomVideoAndAudio(videoOptions: ZegoCustomVideo, audioOptions: ZegoCustomAudio): Promise<ZegoServerResponse>;
    startCaptureScreen(options?: ZegoCaptureScreenVideo): Promise<ZegoServerResponse>;
    startCaptureScreenWithAudio(screenVideoOptions?: ZegoCaptureScreenVideo, screenAudioOptions?: ZegoCaptureScreenAudio): Promise<ZegoServerResponse>;
    stopCaptureAudio(): Promise<boolean>;
    stopCaptureVideo(): Promise<boolean>;
    private _zgp_createStreamView;
    private _zgp_initStreamView;
    playAudio(config?: ZegoLocalAduioOptions): void;
    playCaptureAudio(config?: ZegoLocalAduioOptions): void;
    playVideo(view?: HTMLElement, config?: ZegoLocalViewOptions): void;
    playCaptureVideo(view?: HTMLElement, config?: ZegoLocalViewOptions): void;
    updatePlayVideo(): void;
    updatePlayAudio(): void;
    takeStreamSnapshot(option?: ZegoSnapshotOptions): string;
    resumeVideo(): Promise<void> | void;
    resumeAudio(): Promise<void> | void;
    stopVideo(): void;
    stopAudio(): void;
    stopPlayCaptureVideo(): void;
    stopPlayCaptureAudio(): void;
    setVolume(volume: number): boolean;
    _destroyCacheStream(streams: MediaStream[]): MediaStream[];
    private _zgp_checkAndRecycleStream;
    destroy(): void;
}
